==> plf-community-tomcat-standalone-4.3.0.zip: com/smartgwt/logicalstructure/widgets/tab/TabSetLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.tab;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class TabSetLogicalStructure extends CanvasLogicalStructure {
    public String animateTabScrolling;
    public String canCloseTabs;
    public String canEditTabTitles;
    public String canReorderTabs;
    public String closeTabIcon;
    public String closeTabIconSize;
    public String defaultTabHeight;
    public String defaultTabWidth;
    public String destroyPanes;
    public String locateTabsBy;
    public String moreTabCount;
    public String moreTabImage;
    public String moreTabPaneDefaults;
    public String moreTabPaneProperties;
    public String moreTabProperties;
    public String moreTabTitle;
    public String paneContainerClassName;
    public String paneContainerOverflow;
    public String paneMargin;
    public String pickerButtonHSrc;
    public String pickerButtonSize;
    public String pickerButtonSrc;
    public String pickerButtonVSrc;
    public String scrollerButtonSize;
    public String scrollerHSrc;
    public String scrollerSrc;
    public String scrollerVSrc;
    public String selectedTab;
    public String showMoreTab;
    public String showPaneContainerEdges;
    public String showPartialEdges;
    public String showTabPicker;
    public String showTabScroller;
    public String simpleTabBaseStyle;
    public String skinImgDir;
    public String symmetricEdges;
    public String symmetricPickerButton;
    public String symmetricScroller;
    public String tabBarAlign;
    public String tabBarControls;
    public String tabBarPosition;
    public String tabBarProperties;
    public String tabBarThickness;
    public Tab[] tabs;
    public String titleEditEvent;
    public String titleEditorLeftOffset;
    public String titleEditorProperties;
    public String titleEditorRightOffset;
    public String titleEditorTopOffset;
    public String useIOSTabs;
    public String useSimpleTabs;
}

==> plf-community-tomcat-standalone-5.3.0.zip: com/smartgwt/logicalstructure/widgets/tab/TabSetLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.tab;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class TabSetLogicalStructure extends CanvasLogicalStructure {
    public String addTabButtonIcon;
    public String animateTabScrolling;
    public String ariaCloseableSuffix;
    public String canAddTabs;
    public String canCloseTabs;
    public String canEditTabTitles;
    public String canReorderTabs;
    public String closeTabIcon;
    public String closeTabIconSize;
    public String defaultTabHeight;
    public String defaultTabWidth;
    public String destroyPanes;
    public String editProxyConstructor;
    public String locateTabsBy;
    public String moreTabCount;
    public String moreTabImage;
    public String moreTabPaneDefaults;
    public String moreTabPaneProperties;
    public String moreTabProperties;
    public String moreTabTitle;
    public String paneContainerClassName;
    public String paneContainerOverflow;
    public String paneMargin;
    public String pickerButtonHSrc;
    public String pickerButtonSize;
    public String pickerButtonSrc;
    public String pickerButtonVSrc;
    public String scrollerButtonSize;
    public String scrollerHSrc;
    public String scrollerSrc;
    public String scrollerVSrc;
    public String selectedTab;
    public String showMoreTab;
    public String showPaneContainerEdges;
    public String showPartialEdges;
    public String showTabBar;
    public String showTabPicker;
    public String showTabScroller;
    public String simpleTabBaseStyle;
    public String skinImgDir;
    public String symmetricEdges;
    public String symmetricPickerButton;
    public String symmetricScroller;
    public String tabBarAlignAsString;
    public String tabBarControls;
    public String tabBarPosition;
    public String tabBarProperties;
    public String tabBarThickness;
    public Tab[] tabs;
    public String titleEditEvent;
    public String titleEditorLeftOffset;
    public String titleEditorProperties;
    public String titleEditorRightOffset;
    public String titleEditorTopOffset;
    public String touchPickerButtonSize;
    public String useIOSTabs;
    public String useSimpleTabs;
}
